@@ -41,11 +41,12 @@
 #if defined(FX)
 
 #include "fxdrv.h"
-#include "enums.h"
-#include "tnl.h"
+#include "main/enums.h"
+#include "main/formats.h"
+#include "main/texstore.h"
+#include "tnl/tnl.h"
 #include "tnl/t_context.h"
-#include "swrast.h"
-#include "texstore.h"
+#include "swrast/swrast.h"
 
 
 static void
@@ -91,7 +92,7 @@ fxTexValidate(GLcontext * ctx, struct gl_texture_object *tObj)
       GLint _w, _h, maxSize = 1 << fxMesa->textureMaxLod;
       if ((mml->width > maxSize) || (mml->height > maxSize)) {
          /* need to rescale */
-         GLint texelBytes = texImage->TexFormat->TexelBytes;
+         GLint texelBytes = _mesa_get_format_bytes(texImage->TexFormat->MesaFormat);
          GLvoid *texImage_Data = texImage->Data;
          _w = MIN2(texImage->Width, maxSize);
          _h = MIN2(texImage->Height, maxSize);
@@ -154,8 +155,7 @@ fxTexValidate(GLcontext * ctx, struct gl_texture_object *tObj)
       }
    }
 
-	/* TODO: right format? */
-   ti->baseLevelInternalFormat = tObj->Image[0][minl]->_BaseFormat;
+   ti->baseLevelInternalFormat = tObj->Image[0][minl]->Format;
 
    ti->validated = GL_TRUE;
 
